==================
``formats`` module
==================

.. automodule:: whoosh.formats

Base class
==========

.. autoclass:: Format
	:members:
	

Formats
=======

.. autoclass:: Existence
.. autoclass:: Frequency
.. autoclass:: DocBoosts
.. autoclass:: Positions
.. autoclass:: Characters
.. autoclass:: PositionBoosts
.. autoclass:: CharacterBoosts


